pub struct PlainDecider;Expand description
PlainDecider: Just returns the next work item as a read action
This is for “plain mode” where agents don’t make autonomous decisions but simply execute the work assigned to them.