suggest_orchestration

Function suggest_orchestration 

pub fn suggest_orchestration(
    specs: &[MutationSpec],
    _ctx: &AnalysisContext,
) -> OrchestrationStrategy
Extract a grouping key from a target string Suggest the best orchestration strategy based on specs and context